import React, { useState, useEffect } from "react";
import "./App.css";

const App = () => {
  const [currencyData, setCurrencyData] = useState([]);
  const [amount, setAmount] = useState(1);
  const [fromCurrency, setFromCurrency] = useState("USD");
  const [toCurrency, setToCurrency] = useState("EUR");
  const [convertedAmount, setConvertedAmount] = useState(null);
  const [error, setError] = useState("");

  const apiKey = "36d18b8d443aecdca129f629"; // Dein API Key
  const url = `https://v6.exchangerate-api.com/v6/${apiKey}/latest/${fromCurrency}`;

  useEffect(() => {
    fetch(url)
      .then((response) => response.json())
      .then((data) => {
        setCurrencyData(Object.keys(data.conversion_rates));
      })
      .catch((error) => {
        setError("Fehler beim Laden der Währungsdaten.");
      });
  }, [fromCurrency]);

  const handleAmountChange = (event) => {
    setAmount(event.target.value);
  };

  const handleFromCurrencyChange = (event) => {
    setFromCurrency(event.target.value);
  };

  const handleToCurrencyChange = (event) => {
    setToCurrency(event.target.value);
  };

  const handleConversion = () => {
    fetch(url)
      .then((response) => response.json())
      .then((data) => {
        const rate = data.conversion_rates[toCurrency];
        const result = amount * rate;
        setConvertedAmount(result.toFixed(2));
      })
      .catch((error) => {
        setError("Fehler beim Umrechnen.");
      });
  };

  return (
    <div className="currency-converter">
      <h1>Währungsumrechner</h1>
      <input
        type="number"
        value={amount}
        onChange={handleAmountChange}
        placeholder="Betrag"
      />
      <select value={fromCurrency} onChange={handleFromCurrencyChange}>
        {currencyData.map((currency) => (
          <option key={currency} value={currency}>
            {currency}
          </option>
        ))}
      </select>
      <span>in</span>
      <select value={toCurrency} onChange={handleToCurrencyChange}>
        {currencyData.map((currency) => (
          <option key={currency} value={currency}>
            {currency}
          </option>
        ))}
      </select>
      <button onClick={handleConversion}>Umrechnen</button>
      {convertedAmount && (
        <p>
          {amount} {fromCurrency} = {convertedAmount} {toCurrency}
        </p>
      )}
      {error && <p className="error">{error}</p>}
    </div>
  );
};

export default App;
